SurfaceInstruction

Enum SurfaceInstruction 

pub enum SurfaceInstruction {
Show 145 variants Span(u32, u32, u32), Label(Ident), FunctionStart, FunctionEnd, Breakpoint, Branch(Ident), ConditionalBranch(Ident, Ident), Return(u32), IndirectCall, Call(u32, Ident), Halt, Print, LoadI32(u32), LoadI64(u32), LoadU32(u32), LoadU64(u32), LoadF32(u32), LoadF64(u32), LoadBool(u32), StoreI32(u32), StoreI64(u32), StoreU32(u32), StoreU64(u32), StoreF32(u32), StoreF64(u32), StoreBool(u32), Dup, HeapAlloc(u32), GetItem, HeapDealloc, HeapReserve, HeapPush, ConstI32(SurfaceValue), ConstI64(SurfaceValue), ConstU32(SurfaceValue), ConstU64(SurfaceValue), ConstF32(SurfaceValue), ConstF64(SurfaceValue), ConstBool(SurfaceValue), ConstString(SurfaceValue), ConstFunctionRef(SurfaceValue), ConstHeapRef(SurfaceValue), AddI32, AddF32, AddI64, AddU32, AddU64, AddF64, SubI32, SubI64, SubU32, SubU64, SubF32, SubF64, MulI32, MulI64, MulU32, MulU64, MulF32, MulF64, DivI32, DivI64, DivU32, DivU64, DivF32, DivF64, RemI32, RemI64, RemU32, RemU64, RemF32, RemF64, NegI32, NegI64, NegF32, NegF64, ShlI32, ShlI64, ShlU32, ShlU64, ShrI32, ShrI64, ShrU32, ShrU64, RolI32, RolI64, RolU32, RolU64, RorI32, RorI64, RorU32, RorU64, BitAndI32, BitAndI64, BitAndU32, BitAndU64, BitOrI32, BitOrI64, BitOrU32, BitOrU64, BitXorI32, BitXorI64, BitXorU32, BitXorU64, Not, And, Or, Xor, EqI32, EqI64, EqU32, EqU64, EqF32, EqF64, NeI32, NeI64, NeU32, NeU64, NeF32, NeF64, LtI32, LtI64, LtU32, LtU64, LtF32, LtF64, GtI32, GtI64, GtU32, GtU64, GtF32, GtF64, LeI32, LeI64, LeU32, LeU64, LeF32, LeF64, GeI32, GeI64, GeU32, GeU64, GeF32, GeF64, HeapLen,
}

Variants



Span(u32, u32, u32)



Label(Ident)



FunctionStart



FunctionEnd



Breakpoint



Branch(Ident)



ConditionalBranch(Ident, Ident)



Return(u32)



IndirectCall



Call(u32, Ident)



Halt



Print



LoadI32(u32)



LoadI64(u32)



LoadU32(u32)



LoadU64(u32)



LoadF32(u32)



LoadF64(u32)



LoadBool(u32)



StoreI32(u32)



StoreI64(u32)



StoreU32(u32)



StoreU64(u32)



StoreF32(u32)



StoreF64(u32)



StoreBool(u32)



Dup



HeapAlloc(u32)

Allocate a full heap object, where the allocation length is the capacity.



GetItem



HeapDealloc



HeapReserve

Reserves n slots (where n is the top value on the stack) that can be pushed to.



HeapPush

Push to a heap_ref that is below capacity.



ConstI32(SurfaceValue)



ConstI64(SurfaceValue)



ConstU32(SurfaceValue)



ConstU64(SurfaceValue)



ConstF32(SurfaceValue)



ConstF64(SurfaceValue)



ConstBool(SurfaceValue)



ConstString(SurfaceValue)



ConstFunctionRef(SurfaceValue)



ConstHeapRef(SurfaceValue)



AddI32



AddF32



AddI64



AddU32



AddU64



AddF64



SubI32



SubI64



SubU32



SubU64



SubF32



SubF64



MulI32



MulI64



MulU32



MulU64



MulF32



MulF64



DivI32



DivI64



DivU32



DivU64



DivF32



DivF64



RemI32



RemI64



RemU32



RemU64



RemF32



RemF64



NegI32



NegI64



NegF32



NegF64



ShlI32



ShlI64



ShlU32



ShlU64



ShrI32



ShrI64



ShrU32



ShrU64



RolI32



RolI64



RolU32



RolU64



RorI32



RorI64



RorU32



RorU64



BitAndI32



BitAndI64



BitAndU32



BitAndU64



BitOrI32



BitOrI64



BitOrU32



BitOrU64



BitXorI32



BitXorI64



BitXorU32



BitXorU64



Not



And



Or



Xor



EqI32



EqI64



EqU32



EqU64



EqF32



EqF64



NeI32



NeI64



NeU32



NeU64



NeF32



NeF64



LtI32



LtI64



LtU32



LtU64



LtF32



LtF64



GtI32



GtI64



GtU32



GtU64



GtF32



GtF64



LeI32



LeI64



LeU32



LeU64



LeF32



LeF64



GeI32



GeI64



GeU32



GeU64



GeF32



GeF64



HeapLen

Pop a heap reference and push the object’s current length as a u64.